==> onos-yang-serializers-xml-2.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/networks/DefaultAugmentedNwNetworks.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.networks;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.Te;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedNwNetworks.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedNwNetworks extends InnerModelObject implements AugmentedNwNetworks {
    protected Te te;

    @Override
    public Te te() {
        return te;
    }

    @Override
    public void te(Te te) {
        this.te = te;
    }

    @Override
    public int hashCode() {
        return Objects.hash(te);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedNwNetworks) {
            DefaultAugmentedNwNetworks other = (DefaultAugmentedNwNetworks) obj;
            return
                Objects.equals(te, other.te);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("te=" + te)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedNwNetworks.
     */
    public DefaultAugmentedNwNetworks() {
    }

}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/networks/DefaultAugmentedNwNetworks.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.networks;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.Te;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedNwNetworks.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedNwNetworks extends InnerModelObject implements AugmentedNwNetworks {
    protected Te te;

    @Override
    public Te te() {
        return te;
    }

    @Override
    public void te(Te te) {
        this.te = te;
    }

    @Override
    public int hashCode() {
        return Objects.hash(te);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedNwNetworks) {
            DefaultAugmentedNwNetworks other = (DefaultAugmentedNwNetworks) obj;
            return
                Objects.deepEquals(te, other.te);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("te=" + te)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedNwNetworks.
     */
    public DefaultAugmentedNwNetworks() {
    }

}
